"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.executeInstruction = exports.getInstructionLength = exports.executeStep = void 0;
const UnknownInstructionError_1 = __importDefault(require("../errors/UnknownInstructionError"));
const addInstruction_1 = __importDefault(require("./addInstruction"));
const executeHalt_1 = __importDefault(require("./executeHalt"));
const executeJump_1 = __importDefault(require("./executeJump"));
const executeJumpIfEqual_1 = __importDefault(require("./executeJumpIfEqual"));
const executeJumpIfLess_1 = __importDefault(require("./executeJumpIfLess"));
const executeMemCopy_1 = __importDefault(require("./executeMemCopy"));
const executeRead_1 = __importDefault(require("./executeRead"));
const putInstruction_1 = __importDefault(require("./putInstruction"));
const subtractionInstruction_1 = __importDefault(require("./subtractionInstruction"));
const executeStep = (cells, programCounter, inputReader) => {
    return {
        previousCells: cells.copy(),
        previousPC: programCounter,
        ...(0, exports.executeInstruction)(cells, programCounter, inputReader)
    };
};
exports.executeStep = executeStep;
const getInstructionLength = (cells, programCounter) => {
    const instructionCode = cells.loadValueFrom(programCounter);
    switch (instructionCode) {
        case 0: return 3;
        case 1: return 4;
        case 2: return 4;
        case 3: return 2;
        case 4: return 4;
        case 5: return 4;
        case 6: return 2;
        case 9: return 1;
        case 7: return 3;
        default: return 0;
    }
};
exports.getInstructionLength = getInstructionLength;
const executeInstruction = (cells, programCounter, inputReader) => {
    const instructionCode = cells.loadValueFrom(programCounter);
    switch (instructionCode) {
        case 0: return (0, putInstruction_1.default)(cells, programCounter);
        case 1: return (0, addInstruction_1.default)(cells, programCounter);
        case 2: return (0, subtractionInstruction_1.default)(cells, programCounter);
        case 3: return (0, executeJump_1.default)(cells, programCounter);
        case 4: return (0, executeJumpIfEqual_1.default)(cells, programCounter);
        case 5: return (0, executeJumpIfLess_1.default)(cells, programCounter);
        case 6: return (0, executeRead_1.default)(cells, programCounter, inputReader);
        case 7: return (0, executeMemCopy_1.default)(cells, programCounter);
        case 9: return (0, executeHalt_1.default)(cells, programCounter);
        default: throw new UnknownInstructionError_1.default(instructionCode);
    }
};
exports.executeInstruction = executeInstruction;
//# sourceMappingURL=instructionsExecutor.js.map