"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Cells = void 0;
const cellDoesNotExistsError_1 = __importDefault(require("./errors/cellDoesNotExistsError"));
const emptyCellError_1 = __importDefault(require("./errors/emptyCellError"));
class Cells {
    maxSize;
    cells;
    constructor(maxSize, registers) {
        this.maxSize = maxSize;
        this.cells = registers;
    }
    static getInstance(maxSize, registers) {
        return new Cells(maxSize, registers.map((value, index) => ({ value, id: index + 1 })));
    }
    loadValueFrom(cellNumber) {
        this.validateCellIsPresent(cellNumber);
        const value = (this.cells[cellNumber - 1] || {}).value;
        if (value !== undefined) {
            return value;
        }
        else {
            throw new emptyCellError_1.default(cellNumber);
        }
    }
    putValueIn(cellNumber, value) {
        this.validateCellIsPresent(cellNumber);
        this.cells[cellNumber - 1].value = value;
    }
    validateCellIsPresent(cellNumber) {
        if (isNaN(cellNumber) || cellNumber < 1 || cellNumber > this.cells.length) {
            throw new cellDoesNotExistsError_1.default(cellNumber);
        }
    }
    copy() {
        return new Cells(this.maxSize, this.cells.map(r => ({ ...r })));
    }
}
exports.Cells = Cells;
exports.default = Cells;
//# sourceMappingURL=registers.js.map